panvar_shiny Run the panvaR shiny implementation. Will launch in a default browser or can navigate to IP address shown.
Source:R/panvar_shiny.R
panvar_shiny.Rdpanvar_shiny Run the panvaR shiny implementation. Will launch in a default browser or can navigate to IP address shown.
Arguments
- display.mode
display mode of shiny app, see documentation for
shiny::runApp()- launch.browser
should browser be launched automatically or not
- ...
arguments passed to
shiny::runApp()